<?php

/**
 * This is the model class for table "METEO".
 *
 * The followings are the available columns in table 'METEO':
 * @property string $Data
 * @property double $GLO
 * @property double $DIF
 * @property double $T_AIR
 * @property double $RH_AIR
 * @property double $PRESS
 * @property double $PREC
 * @property double $WIND_V
 * @property double $WIND_D
 * @property double $Dir_SD
 */
class METEO extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'METEO';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('UTCData', 'required'),
			array('GLO, DIF, T_AIR, RH_AIR, PRESS, PREC, WIND_V, WIND_D, Dir_SD', 'numerical'),
			array('UTCData', 'length', 'max'=>25),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('UTCData, GLO, DIF, T_AIR, RH_AIR, PRESS, PREC, WIND_V, WIND_D, Dir_SD', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'UTCData' => 'UTCData',
			'GLO' => 'Glo',
			'DIF' => 'Dif',
			'T_AIR' => 'T Air',
			'RH_AIR' => 'Rh Air',
			'PRESS' => 'Press',
			'PREC' => 'Prec',
			'WIND_V' => 'Wind V',
			'WIND_D' => 'Wind D',
			'Dir_SD' => 'Dir Sd',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.
		$criteria=new CDbCriteria;
		
		$criteria->order='UTCData DESC';

		$criteria->compare('UTCData',$this->UTCData,true);
		$criteria->compare('GLO',$this->GLO);
		$criteria->compare('DIF',$this->DIF);
		$criteria->compare('T_AIR',$this->T_AIR);
		$criteria->compare('RH_AIR',$this->RH_AIR);
		$criteria->compare('PRESS',$this->PRESS);
		$criteria->compare('PREC',$this->PREC);
		$criteria->compare('WIND_V',$this->WIND_V);
		$criteria->compare('WIND_D',$this->WIND_D);
		$criteria->compare('Dir_SD',$this->Dir_SD);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'pagination' => array(
				'pageSize' => Yii::app()->user->getState( 'pageSize', Yii::app()->params[ 'defaultPageSize' ] ),
			),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return METEO the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
	
	public function getlast7days(){
		$connection = new CDbConnection(Yii::app()->db->connectionString,Yii::app()->db->username,Yii::app()->db->password);
		$connection->active=true;
		$sql="SELECT * FROM `METEO` ORDER BY UTCData DESC LIMIT 2016";
		$command=$connection->createCommand($sql);
		$data=$command->queryAll();
		return $data;
	}
}
